@@ -18,13 +18,13 @@ def win_exec(command: List[str]) -> dict:
     returns:
         - dict containing output of command on output key or error on error key.
     """
-    result = subprocess.run(["powershell", " ".join(command)], check=False)
-    if result.stderr:
-        return {"error": result.stderr.decode(encoding="unicode_escape")}
-    output = ""
-    if result.stdout:
-        output = result.stdout.decode(encoding="unicode_escape")
-    return {"output": output}
+    result = subprocess.run(
+        ["powershell", " ".join(command)], check=False, text=True, capture_output=True
+    )
+    return {
+        "error": result.stderr.rstrip().lstrip(),
+        "output": result.stdout.rstrip().lstrip(),
+    }
 
 
 def posix_exec(command: List[str]) -> dict:
@@ -38,10 +38,13 @@ def posix_exec(command: List[str]) -> dict:
     returns:
         - dict containing output of command on output key or error on error key.
     """
-    result = subprocess.run(["/bin/bash", "-c", " ".join(command)], check=False)
-    if result.stderr:
-        return {"error": result.stderr.decode()}
-    output = ""
-    if result.stdout:
-        output = result.stdout.decode()
-    return {"output": output}
+    result = subprocess.run(
+        ["/bin/bash", "-c", " ".join(command)],
+        check=False,
+        text=True,
+        capture_output=True,
+    )
+    return {
+        "error": result.stderr.rstrip().lstrip(),
+        "output": result.stdout.rstrip().lstrip(),
+    }
