@@ -93,7 +93,7 @@ def get_storage(boost_data: dict, variables: List[str]) -> dict:
                     boost_data["vars"][clean_var].replace("exec ", "").split(" ")
                 )
                 cmd_output = call_command(cmd, args)
-                if "error" in cmd_output:
+                if "error" in cmd_output and cmd_output["error"]:
                     return cmd_output
                 value = cmd_output["output"]
             else:
@@ -136,14 +136,23 @@ def main() -> int:
 
     for i, cmd in enumerate(commands):
         variables = re.findall("{.*?}", cmd)
+        clean_cmd = cmd
         for var in variables:
+            print_value = "****"
+            if "secret" not in var:
+                print_value = storage[var]
+            # command containing secret vars values
             cmd = cmd.replace(var, storage[var])
-        print(Fore.GREEN + f"-> [{i + 1}/{total_commands}] - {cmd}")
+            # command containing secret vars replaced values for printing
+            clean_cmd = clean_cmd.replace(var, print_value)
+
+        print(Fore.GREEN + f"-> [{i + 1}/{total_commands}] - {clean_cmd}")
         cmd, *args = cmd.split(" ")
         output = call_command(cmd, args)
+
         if "error" in output:
             print(Fore.RED + output["error"])
-            return 1
+        print(Fore.WHITE + output["output"])
     return 0
 
 
